@@ -59,6 +59,27 @@ sub unwind_to_string_list {
     return $res;
 }
 
+sub TO_JSON {
+    my $self = shift;
+    my $res = {
+        message => $self->message
+    };
+
+    $res->{instance_path} = $self->instance_path
+        if $self->instance_path;
+    $res->{schema_path} = $self->schema_path
+        if $self->schema_path;
+
+    if (@{$self->context}) {
+        $res->{context} = [
+            map { $_->TO_JSON }
+            @{$self->context}
+            ];
+    }
+
+    return $res;
+}
+
 1;
 
 __END__
@@ -73,7 +94,7 @@ JSONSchema::Validator::Error - Error class
 
 =head1 VERSION
 
-version 0.008
+version 0.010
 
 =head1 AUTHORS
 
